:orphan:

.. _whats_new_v0x_history:

*****************************
Version v0.x release history
*****************************

Links to the "What's New?" sections of the documentation for all ``v0.x`` versions of the code appear below:


.. toctree::
   :maxdepth: 1

   whats_new_0.1.0